package samples.math.assertion;

import ood.dbc.Assertion;
import samples.math.PositiveDouble;

public class PositiveDoubleAssertion implements Assertion {

	private PositiveDouble pd;

	/**
	 * Pass the checked object to the assertion class.
	 * Ensured to be called before any other method of the assertion class.
	 * @param obj the checked object.
	 * @see ood.dbc.Assertion#setObject(java.lang.Object)
	 */
	public void setObject(Object obj) {
		pd = (PositiveDouble) obj;
	}

	/**
	 * Checks the object's invariant.
	 * @return true if the object's invariant is correct, false otherwise. 
	 * @see ood.dbc.Assertion#invariant()
	 */
	public boolean invariant() {
		return pd.getValue() >= 0;
	}

	public boolean pre_setValue(double d) {
		return d >= 0;
	}

	public boolean post_getSqrt(double result) {
		// Question: why do we use this condition and not simple eauility (==) ?
		return Math.abs(result * result - pd.getValue()) <= 0.001;
	}

	public boolean post_getSum(double e, double result) {
		return result == pd.getValue() + e;
	}

	public boolean pre_add(double e) {
		return pd.getValue() + e >= 0;
	}

}
