package samples.shapes.assertion;

import ood.dbc.Assertion;
import samples.shapes.Circle;
import samples.shapes.Position;

public class CircleAssertion implements Assertion {

	/**
	 * The checked circle
	 */
	private Circle circle;

	/**
	 * Pass the checked object to the assertion class.
	 * Ensured to be called before any other method of the assertion class.
	 * @param obj the checked object.
	 * @see ood.dbc.Assertion#setObject(java.lang.Object)
	 */
	public void setObject(Object obj) {
		circle = (Circle) obj;
	}

	/**
	 * Checks the object's invariant.
	 * @return true if the object's invariant is correct, false otherwise. 
	 * @see ood.dbc.Assertion#invariant()
	 */
	public boolean invariant() {
		return AssertionUtils.isNotNull(circle.getCenter())
			&& AssertionUtils.isPositiveNumber(circle.getRadius());
	}

	public boolean pre_setCenter(Position center) {
		return AssertionUtils.isNotNull(circle.getCenter());
	}

	public boolean pre_setRadius(double radius) {
		return AssertionUtils.isPositiveNumber(circle.getRadius());
	}

	public boolean post_getArea(double result) {
		double radius = circle.getRadius();
		return result == (4.0 * Math.PI * radius * radius);
	}

	public boolean post_getPerimeter(double result) {
		double radius = circle.getRadius();
		return result == (2.0 * Math.PI * radius);
	}
}
