package samples.shapes.assertion;

import ood.dbc.Assertion;
import samples.shapes.Rectangle;

public class RectangleAssertion implements Assertion {

	/**
	 * The checked rectangle
	 */
	private Rectangle rectangle;

	/**
	 * Pass the checked object to the assertion class.
	 * Ensured to be called before any other method of the assertion class.
	 * @param obj the checked object.
	 * @see ood.dbc.Assertion#setObject(java.lang.Object)
	 */
	public void setObject(Object obj) {
		rectangle = (Rectangle) obj;
	}

	/**
	 * Checks the object's invariant.
	 * @return true if the object's invariant is correct, false otherwise. 
	 * @see ood.dbc.Assertion#invariant()
	 */
	public boolean invariant() {
		return AssertionUtils.isNotNull(rectangle.getBottomLeftCorner())
			&& AssertionUtils.isPositiveNumber(rectangle.getWidth())
			&& AssertionUtils.isPositiveNumber(rectangle.getHeight());
	}

	public boolean pre_setWidth(double width) {
		return AssertionUtils.isPositiveNumber(width);
	}

	public boolean pre_setHeight(double height) {
		return AssertionUtils.isPositiveNumber(height);
	}

	public boolean post_getArea(double result) {
		return result == (rectangle.getWidth() * rectangle.getHeight());
	}

	public boolean post_getPerimeter(double result) {
		return result == (2.0 * (rectangle.getWidth() + rectangle.getHeight()));
	}

}
